#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Script for taking the datapoints for the solvation curve, and generating
the polynomial fit data and also the plots.

@author: mark
"""

import logging
import resultsanalysis.resultsoutput.plottinginput as plottinginput
import solventmapcreator.io.polynomialdatawriter as polynomialdatawriter
import solventmapcreator.io.solvationenergyreader as solvationenergyreader

logging.basicConfig()
LOGGER = logging.getLogger(__name__)
LOGGER.setLevel(logging.WARN)

def plot_energies_from_file(free_energy_filename, polynomial_order):
    """This creates in the plotting information, and outputs a plot to file.
    """
    plot_data = parse_energies_create_plot_input_data(free_energy_filename, polynomial_order)
    return plottinginput.create_scatter_graph_with_polynomial(plot_data)

def parse_energies_create_plot_input_data(free_energy_filename, polynomial_order):
    """This creates the input data for a plot. This overrides the default figure
    label, so that the figures can be distinguished based on the solvent.
    """
    datapoints = parse_free_energy_from_file_with_data_arrays(free_energy_filename)
    plot_data = datapoints.generateScatterPlotParameters(label_type='', polynomial_order=polynomial_order)
    plot_data['figure_label'] = free_energy_filename.replace('.xml', '')
    return plot_data

def parse_energies_and_output_poly_data(free_energy_filename, order_list, poly_filename):
    """This reads in the energy information, and then outputs the polynomial
    information to file.
    """
    datapoints = parse_free_energy_from_file_with_data_arrays(free_energy_filename)
    return write_poly_data_to_file(datapoints, order_list, poly_filename)

def write_poly_data_to_file(datapoints, order_list, filename):
    """This calculates the polynomial information, and then outputs the
    information to file.
    """
    return polynomialdatawriter.write_poly_data_to_file(datapoints, order_list, filename)

def parse_free_energy_from_file_with_data_arrays(filename):
    """This reads in the information form file to a Datapoints object, and
    creates the data arrays.
    """
    return solvationenergyreader.parse_free_energy_from_file_with_data_arrays(filename)
